summaryrefslogtreecommitdiff
path: root/js/src/jsapi-tests/testSameValue.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'js/src/jsapi-tests/testSameValue.cpp')
-rw-r--r--js/src/jsapi-tests/testSameValue.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/js/src/jsapi-tests/testSameValue.cpp b/js/src/jsapi-tests/testSameValue.cpp
index 666da40360..50d2208d86 100644
--- a/js/src/jsapi-tests/testSameValue.cpp
+++ b/js/src/jsapi-tests/testSameValue.cpp
@@ -4,6 +4,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
+#include "js/Equality.h" // JS::SameValue
#include "jsapi-tests/tests.h"
BEGIN_TEST(testSameValue)
@@ -11,7 +12,7 @@ BEGIN_TEST(testSameValue)
/*
* NB: passing a double that fits in an integer jsval is API misuse. As a
* matter of defense in depth, however, JS_SameValue should return the
* correct result comparing a positive-zero double to a negative-zero
* double, and this is believed to be the only way to make such a
* comparison possible.
@@ -19,7 +20,7 @@ BEGIN_TEST(testSameValue)
JS::RootedValue v1(cx, JS::DoubleValue(0.0));
JS::RootedValue v2(cx, JS::DoubleValue(-0.0));
bool same;
- CHECK(JS_SameValue(cx, v1, v2, &same));
+ CHECK(JS::SameValue(cx, v1, v2, &same));
CHECK(!same);
return true;
}
@@ -11,7 +12,7 @@ BEGIN_TEST(testSameValue)
/*
* NB: passing a double that fits in an integer jsval is API misuse. As a
- * matter of defense in depth, however, JS_SameValue should return the
+ * matter of defense in depth, however, JS::SameValue should return the
* correct result comparing a positive-zero double to a negative-zero
* double, and this is believed to be the only way to make such a